* File changes content without changing etag
* File changes content and etag
* File download interupts
* File disapers at second download
* file get "429 - too many request" errors and "Retry-After" header
* File has mime type in header (Content-Type) but no filename in content-disposition
